YARP 2.2.7 (2010-05-04)                                                {#v2_2_7}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.2.6...v2.2.7`):

```
    52	Paul Fitzpatrick <paulfitz@alum.mit.edu>
    18	Alessandro Scalzo <alessandro.scalzo@iit.it>
    17	Lorenzo Natale <lorenzo.natale@iit.it>
    10	Ugo Pattacini <ugo.pattacini@iit.it>
     2	Daniel Krieg <krieg@fias.uni-frankfurt.de>
     1	Arjan Gijsberts <arjan.gijsberts@idiap.ch>
```
